netapp_ontap.models.fcp_service_target API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fcp_service_target`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FcpServiceTargetSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcpServiceTarget object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `name GET`

    The target name of the FC Protocol service. This is generated for the SVM during POST.
    The FC Protocol target name is a world wide node name (WWNN).
    If required, the target name can be modified using the ONTAP command line.

    Example: 20:00:00:50:56:bb:b2:4b